@@ -162,7 +162,7 @@ def can_put_annotation(task: Task, my_account_id: str) -> bool:
     return len(task["histories_by_phase"]) == 0 or task["account_id"] == my_account_id
 
 
-def get_message_for_i18n(internationalization_message: Dict[str, Any], lang: str = "en-US") -> Optional[str]:
+def get_message_for_i18n(internationalization_message: Dict[str, Any], lang: str = "en-US") -> str:
     """
     アノテーション仕様で使われている`InternalizationMessage`クラスの値から、指定された言語のメッセージを取得する。
 
@@ -171,7 +171,7 @@ def get_message_for_i18n(internationalization_message: Dict[str, Any], lang: str
         lang: 取得したいメッセージに対応する言語コード。`en-US`または`ja-JP`のみサポートしています。
 
     Returns:
-        指定した言語に対応するメッセージ。見つからない場合はNoneを返します。
+        指定した言語に対応するメッセージ。
 
     Raises:
         ValueError: 引数langに対応するメッセージが見つからない場合
